@@ -4,10 +4,16 @@ from scipy.stats import gaussian_kde
 import warnings
 
 try:
+    # pandas < 0.25
     from pandas.plotting._tools import (_subplots, _flatten)
-except:
-    #TODO this is a quick fix for #38
-    from pandas.plotting._matplotlib.tools import (_subplots, _flatten)
+except ImportError:
+    try:
+        #pandas >= 0.25, <1.2.0
+        from pandas.plotting._matplotlib.tools import (_subplots, _flatten)
+    except ImportError:
+        #pandas >= 1.2.0
+        from pandas.plotting._matplotlib.tools import create_subplots as _subplots
+        from pandas.plotting._matplotlib.tools import flatten_axes as _flatten
 
 from pandas import (DataFrame, Series)
 from pandas.core.dtypes.common import is_number
@@ -88,6 +94,7 @@ def joyplot(data, column=None, by=None, grid=False,
             x_range=None,
             title=None,
             colormap=None,
+            color=None,
             **kwds):
     """
     Draw joyplot of a DataFrame, or appropriately nested collection,
@@ -127,6 +134,9 @@ def joyplot(data, column=None, by=None, grid=False,
     hist : boolean, default False
     bins : integer, default 10
         Number of histogram bins to be used
+    color : color or colors to be used in the plots. It can be:
+        a string or anything interpretable as color by matplotib;
+        a list of colors. See docs / examples for more details.
     kwds : other plotting keyword arguments
         To be passed to hist/kde plot function
     """
@@ -236,6 +246,7 @@ def joyplot(data, column=None, by=None, grid=False,
                     range_style=range_style, x_range=x_range,
                     title=title,
                     colormap=colormap,
+                    color=color,
                     **kwds)
 
 ###########################################
@@ -376,13 +387,14 @@ def _joyplot(data,
 
     def _get_color(i, num_axes, j, num_subgroups):
         if isinstance(color, list):
-            return color[j]
+            return color[j] if num_subgroups > 1 else color[i]
         elif color is not None:
             return color
         elif isinstance(colormap, list):
             return colormap[j](i/num_axes)
         elif color is None and colormap is None:
-            return plt.rcParams['axes.prop_cycle'].by_key()['color'][j]
+            num_cycle_colors = len(plt.rcParams['axes.prop_cycle'].by_key()['color'])
+            return plt.rcParams['axes.prop_cycle'].by_key()['color'][j % num_cycle_colors]
         else:
             return colormap(i/num_axes)
 
@@ -405,7 +417,7 @@ def _joyplot(data,
 
     # The legend must be drawn in the last axis if we want it at the bottom.
     if loc in (3, 4, 8) or 'lower' in str(loc):
-        legend_axis = num_axis - 1
+        legend_axis = num_axes - 1
     else:
         legend_axis = 0
 
@@ -415,7 +427,7 @@ def _joyplot(data,
     if sublabels is not None:
         assert all(len(g) == len(sublabels) for g in data)
     if isinstance(color, list):
-        assert all(len(g) == len(color) for g in data)
+        assert all(len(g) <= len(color) for g in data)
     if isinstance(colormap, list):
         assert all(len(g) == len(colormap) for g in data)
 
